dj-blacksmith
=============

.. image:: https://github.com/mardiros/dj-blacksmith/actions/workflows/gh-pages.yml/badge.svg
   :target: https://mardiros.github.io/dj-blacksmith/
   :alt: Documentation

.. image:: https://github.com/mardiros/dj-blacksmith/actions/workflows/main.yml/badge.svg
   :target: https://github.com/mardiros/dj-blacksmith/actions/workflows/main.yml
   :alt: Continuous Integration

.. image:: https://codecov.io/gh/mardiros/dj-blacksmith/branch/main/graph/badge.svg?token=GMCE9HQE98
   :target: https://codecov.io/gh/mardiros/dj-blacksmith
   :alt: Coverage

Django bindings for `Blacksmith`_ rest api client.

.. _`Blacksmith`: https://mardiros.github.io/blacksmith/
